@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import bisect
 import collections
 import copy
@@ -367,8 +368,6 @@ class MultiImageMixDataset:
 
             if 'mix_results' in results:
                 results.pop('mix_results')
-            if 'img_scale' in results:
-                results.pop('img_scale')
 
         return results
 
