@@ -3,8 +3,9 @@ import sys
 from inspect import signature
 
 import torch
+from mmcv.ops import batched_nms
 
-from mmdet.core import bbox_mapping_back, merge_aug_proposals, multiclass_nms
+from mmdet.core import bbox_mapping_back, merge_aug_proposals
 
 if sys.version_info >= (3, 7):
     from mmdet.utils.contextmanagers import completed
@@ -33,7 +34,8 @@ class BBoxTestMixin(object):
                 with shape (n,)
         """
         outs = self.forward(feats)
-        results_list = self.get_bboxes(*outs, img_metas, rescale=rescale)
+        results_list = self.get_bboxes(
+            *outs, img_metas=img_metas, rescale=rescale)
         return results_list
 
     def aug_test_bboxes(self, feats, img_metas, rescale=False):
@@ -61,10 +63,7 @@ class BBoxTestMixin(object):
         # check with_nms argument
         gb_sig = signature(self.get_bboxes)
         gb_args = [p.name for p in gb_sig.parameters.values()]
-        if hasattr(self, '_get_bboxes'):
-            gbs_sig = signature(self._get_bboxes)
-        else:
-            gbs_sig = signature(self._get_bboxes_single)
+        gbs_sig = signature(self._get_bboxes_single)
         gbs_args = [p.name for p in gbs_sig.parameters.values()]
         assert ('with_nms' in gb_args) and ('with_nms' in gbs_args), \
             f'{self.__class__.__name__}' \
@@ -72,30 +71,34 @@ class BBoxTestMixin(object):
 
         aug_bboxes = []
         aug_scores = []
-        aug_factors = []  # score_factors for NMS
+        aug_labels = []
         for x, img_meta in zip(feats, img_metas):
             # only one image in the batch
             outs = self.forward(x)
-            bbox_inputs = outs + (img_meta, self.test_cfg, False, False)
-            bbox_outputs = self.get_bboxes(*bbox_inputs)[0]
+            bbox_outputs = self.get_bboxes(
+                *outs,
+                img_metas=img_meta,
+                cfg=self.test_cfg,
+                rescale=False,
+                with_nms=False)[0]
             aug_bboxes.append(bbox_outputs[0])
             aug_scores.append(bbox_outputs[1])
-            # bbox_outputs of some detectors (e.g., ATSS, FCOS, YOLOv3)
-            # contains additional element to adjust scores before NMS
             if len(bbox_outputs) >= 3:
-                aug_factors.append(bbox_outputs[2])
+                aug_labels.append(bbox_outputs[2])
 
         # after merging, bboxes will be rescaled to the original image size
         merged_bboxes, merged_scores = self.merge_aug_bboxes(
             aug_bboxes, aug_scores, img_metas)
-        merged_factors = torch.cat(aug_factors, dim=0) if aug_factors else None
-        det_bboxes, det_labels = multiclass_nms(
-            merged_bboxes,
-            merged_scores,
-            self.test_cfg.score_thr,
-            self.test_cfg.nms,
-            self.test_cfg.max_per_img,
-            score_factors=merged_factors)
+        merged_labels = torch.cat(aug_labels, dim=0) if aug_labels else None
+
+        if merged_bboxes.numel() == 0:
+            det_bboxes = torch.cat([merged_bboxes, merged_scores[:, None]], -1)
+            return det_bboxes, merged_labels
+
+        det_bboxes, keep_idxs = batched_nms(merged_bboxes, merged_scores,
+                                            merged_labels, self.test_cfg.nms)
+        det_bboxes = det_bboxes[:self.test_cfg.max_per_img]
+        det_labels = merged_labels[keep_idxs][:self.test_cfg.max_per_img]
 
         if rescale:
             _det_bboxes = det_bboxes
@@ -122,7 +125,7 @@ class BBoxTestMixin(object):
                 where 5 represent (tl_x, tl_y, br_x, br_y, score).
         """
         rpn_outs = self(x)
-        proposal_list = self.get_bboxes(*rpn_outs, img_metas)
+        proposal_list = self.get_bboxes(*rpn_outs, img_metas=img_metas)
         return proposal_list
 
     def aug_test_rpn(self, feats, img_metas):
@@ -168,7 +171,7 @@ class BBoxTestMixin(object):
                     sleep_interval=sleep_interval):
                 rpn_outs = self(x)
 
-            proposal_list = self.get_bboxes(*rpn_outs, img_metas)
+            proposal_list = self.get_bboxes(*rpn_outs, img_metas=img_metas)
             return proposal_list
 
     def merge_aug_bboxes(self, aug_bboxes, aug_scores, img_metas):
