@@ -1,4 +1,7 @@
+# Copyright (c) OpenMMLab. All rights reserved.
+from .brick_wrappers import AdaptiveAvgPool2d, adaptive_avg_pool2d
 from .builder import build_linear_layer, build_transformer
+from .ckpt_convert import pvt_convert
 from .conv_upsample import ConvUpsample
 from .csp_layer import CSPLayer
 from .gaussian_target import gaussian_radius, gen_gaussian_target
@@ -11,7 +14,8 @@ from .positional_encoding import (LearnedPositionalEncoding,
 from .res_layer import ResLayer, SimplifiedBasicBlock
 from .se_layer import SELayer
 from .transformer import (DetrTransformerDecoder, DetrTransformerDecoderLayer,
-                          DynamicConv, Transformer)
+                          DynamicConv, PatchEmbed, Transformer, nchw_to_nlc,
+                          nlc_to_nchw)
 
 __all__ = [
     'ResLayer', 'gaussian_radius', 'gen_gaussian_target',
@@ -19,5 +23,7 @@ __all__ = [
     'build_transformer', 'build_linear_layer', 'SinePositionalEncoding',
     'LearnedPositionalEncoding', 'DynamicConv', 'SimplifiedBasicBlock',
     'NormedLinear', 'NormedConv2d', 'make_divisible', 'InvertedResidual',
-    'SELayer', 'interpolate_as', 'ConvUpsample', 'CSPLayer'
+    'SELayer', 'interpolate_as', 'ConvUpsample', 'CSPLayer',
+    'adaptive_avg_pool2d', 'AdaptiveAvgPool2d', 'PatchEmbed', 'nchw_to_nlc',
+    'nlc_to_nchw', 'pvt_convert'
 ]
